<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="about_dialog.ui" line="32"/>
        <source>About Mozc</source>
        <translation>Mozcについて</translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="59"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="about_dialog.ui" line="80"/>
        <source>Copyright © 2015 Google Inc. All Rights Reserved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="95"/>
        <source>&lt;html&gt;&lt;body&gt;Mozc is made possible by &lt;a href=&quot;file://credits_en.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;open source software&lt;/span&gt;&lt;/a&gt;.&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;body&gt;Mozcは&lt;a href=&quot;file://credits_ja.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;オープンソースソフトウェア&lt;/span&gt;&lt;/a&gt;を利用しています。&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="133"/>
        <source>&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;https://github.com/google/mozc&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;product information&lt;/span&gt;&lt;/a&gt; &lt;a href=&quot;https://github.com/google/mozc/issues&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;issues&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;https://github.com/google/mozc&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;製品情報&lt;/span&gt;&lt;/a&gt; &lt;a href=&quot;https://github.com/google/mozc/issues&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;issues&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;body&gt;Google &lt;a href=&quot;file://privacy_en.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;privacy policy&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;html&gt;&lt;body&gt;Google &lt;a href=&quot;file://privacy_ja.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;プライバシー ポリシー&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="174"/>
        <source>Mozc</source>
        <translation>Mozc</translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="197"/>
        <source>0.0.0.0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
